
(sec_rate_maps)=
# Rate Maps


```{eval-rst}
.. todo:: Need to fill out the content here following existing patterns.
```

{class}`.RateMap`
: Vary rates along a genome                

**Creating RateMaps**                                                                

{meth}`.RateMap.uniform`                   
: A RateMap with one rate                  

{meth}`.RateMap.slice`                     
: Slice out a portion of a RateMap         

**Computing rates**                                                                  

{meth}`.RateMap.mean_rate`                 
: Weighted average rate                    

{meth}`.RateMap.get_rate`                  
: Compute rate at a position               

